@@ -9,8 +9,10 @@ from typing import Any, Optional
 import sqlmodel as sqm
 from lamin_logger import logger
 from natsort import natsorted
+from packaging.version import parse as vparse
 
 from ._db import insert
+from ._migrations import generate_alembic_ini, modify_alembic_ini
 from ._settings_instance import InstanceSettings
 from ._settings_user import UserSettings
 from ._setup_schema import create_schema_if_not_exists, get_schema_module_name
@@ -51,11 +53,18 @@ def check_migrate(
             )
             version_table = getattr(table_loc, f"version_{schema_id}")
             versions = session.exec(sqm.select(version_table.v)).all()
-            versions = natsorted(versions)
+            versions = natsorted(versions)  # latest version is last
 
         current_version = schema_module.__version__
 
         if current_version not in versions and len(versions) > 0:
+            if vparse(current_version) < vparse(versions[-1]):  # type: ignore
+                raise RuntimeError(
+                    f"You are trying to connect to a DB that runs v{versions[-1]} "
+                    f"of schema module {schema_name}.\n"
+                    f"Please run `pip install {schema_module_name}=={versions[-1]}`, "
+                    "or install the latest version from GitHub."
+                )
             logger.info(
                 f"Schema {schema_name} v{versions[-1]} is not up to date"
                 f" with {current_version}."
@@ -89,16 +98,20 @@ def check_migrate(
                 )
                 return "migrate-failed"
 
-            status.append(
-                migrate(
-                    version=current_version,
-                    usettings=usettings,
-                    isettings=isettings,
-                    schema_name=schema_name,
-                    schema_id=schema_id,
-                    schema_module=schema_module,
-                )
+            generate_alembic_ini(
+                package_name=schema_module_name,
+                migrations_path=Path(schema_module.__file__).parent / "migrations",  # type: ignore  # noqa
+                schema_id=schema_id,
             )
+            migrate_status = migrate(
+                version=current_version,
+                usettings=usettings,
+                isettings=isettings,
+                schema_name=schema_name,
+                schema_id=schema_id,
+                schema_module=schema_module,
+            )
+            status.append(migrate_status)
         else:
             status.append("migrate-unnecessary")
 
@@ -112,36 +125,6 @@ def check_migrate(
         return "migrate-unnecessary"
 
 
-def modify_alembic_ini(
-    filepath: Path, isettings: InstanceSettings, schema_name: str, revert: bool = False
-):
-    schema_module_path = (
-        get_schema_module_name(schema_name).replace(".", "/") + "/migrations"
-    )
-    sl_from, sl_to = schema_module_path, "migrations"
-    url_from = "sqlite:///testdb/testdb.lndb"
-    url_to_sqlite = f"sqlite:///{isettings._sqlite_file_local}"
-    url_to = url_to_sqlite if isettings.dialect == "sqlite" else isettings.db
-
-    if revert:
-        sl_from, sl_to = sl_to, sl_from
-        url_from, url_to = url_to, url_from
-
-    with open(filepath) as f:
-        content = f.read()
-
-    content = content.replace(
-        f"script_location = {sl_from}",
-        f"script_location = {sl_to}",
-    ).replace(
-        f"sqlalchemy.url = {url_from}",
-        f"sqlalchemy.url = {url_to}",
-    )
-
-    with open(filepath, "w") as f:
-        f.write(content)
-
-
 def migrate(
     *,
     version: str,
