@@ -151,7 +151,7 @@ class InstanceSettings:
         if self._db is None or self._db.startswith("sqlite://"):
             return "sqlite"
         else:
-            assert self._db.startswith("postgresql://")
+            assert self._db.startswith("postgresql")
             return "postgresql"
 
     @property
